You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@hive.apache.org by sp...@apache.org on 2016/07/19 16:38:46 UTC

hive git commit: HIVE-14254: Correct the hive version by changing "svn" to "git" (Tao Li, reviewed by Sergio Pena)

Repository: hive
Updated Branches:
  refs/heads/master 137365170 -> d8168cc35


HIVE-14254: Correct the hive version by changing "svn" to "git" (Tao Li, reviewed by Sergio Pena)


Project: http://git-wip-us.apache.org/repos/asf/hive/repo
Commit: http://git-wip-us.apache.org/repos/asf/hive/commit/d8168cc3
Tree: http://git-wip-us.apache.org/repos/asf/hive/tree/d8168cc3
Diff: http://git-wip-us.apache.org/repos/asf/hive/diff/d8168cc3

Branch: refs/heads/master
Commit: d8168cc3510d378d6bfa956cf7a372e49e300af1
Parents: 1373651
Author: Tao Li <tl...@hortonworks.com>
Authored: Tue Jul 19 11:38:18 2016 -0500
Committer: Sergio Pena <se...@cloudera.com>
Committed: Tue Jul 19 11:38:18 2016 -0500

----------------------------------------------------------------------
 .../src/java/org/apache/hive/common/HiveVersionAnnotation.java | 4 ++--
 .../src/java/org/apache/hive/common/util/HiveVersionInfo.java  | 6 +++---
 2 files changed, 5 insertions(+), 5 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/hive/blob/d8168cc3/common/src/java/org/apache/hive/common/HiveVersionAnnotation.java
----------------------------------------------------------------------
diff --git a/common/src/java/org/apache/hive/common/HiveVersionAnnotation.java b/common/src/java/org/apache/hive/common/HiveVersionAnnotation.java
index 140bdbc..1ef725b 100644
--- a/common/src/java/org/apache/hive/common/HiveVersionAnnotation.java
+++ b/common/src/java/org/apache/hive/common/HiveVersionAnnotation.java
@@ -58,12 +58,12 @@ public @interface HiveVersionAnnotation {
   String date();
 
   /**
-   * Get the url for the subversion repository.
+   * Get the url for the git repository.
    */
   String url();
 
   /**
-   * Get the subversion revision.
+   * Get the git revision.
    * @return the revision number as a string (eg. "451451")
    */
   String revision();

http://git-wip-us.apache.org/repos/asf/hive/blob/d8168cc3/common/src/java/org/apache/hive/common/util/HiveVersionInfo.java
----------------------------------------------------------------------
diff --git a/common/src/java/org/apache/hive/common/util/HiveVersionInfo.java b/common/src/java/org/apache/hive/common/util/HiveVersionInfo.java
index 3627150..885d8f5 100644
--- a/common/src/java/org/apache/hive/common/util/HiveVersionInfo.java
+++ b/common/src/java/org/apache/hive/common/util/HiveVersionInfo.java
@@ -66,7 +66,7 @@ public class HiveVersionInfo {
   }
 
   /**
    * Get the subversion revision number for the root directory
    * @return the revision number, eg. "451451"
    */
   public static String getRevision() {
@@ -98,7 +98,7 @@ public class HiveVersionInfo {
   }
 
   /**
    * Get the subversion URL for the root Hive directory.
    */
   public static String getUrl() {
     return version != null ? version.url() : "Unknown";
@@ -126,7 +126,7 @@ public class HiveVersionInfo {
   public static void main(String[] args) {
     LOG.debug("version: "+ version);
     System.out.println("Hive " + getVersion());
-    System.out.println("Subversion " + getUrl() + " -r " + getRevision());
+    System.out.println("Git " + getUrl() + " -r " + getRevision());
     System.out.println("Compiled by " + getUser() + " on " + getDate());
     System.out.println("From source with checksum " + getSrcChecksum());
   }
@@ -66,7 +66,7 @@ public class HiveVersionInfo {
 
   /**
-   * Get the subversion revision number for the root directory
+   * Get the git revision number for the root directory
    * @return the revision number, eg. "451451"
    */
@@ -98,7 +98,7 @@ public class HiveVersionInfo {
 
   /**
-   * Get the subversion URL for the root Hive directory.
+   * Get the git URL for the root Hive directory.
    */
   public static String getUrl() {